"""sportly.nhl.endpoints — NHL Web API endpoint submodules.

Submodules
----------
- ``games``    — ``boxscore()``, ``play_by_play()``, ``landing()``
- ``schedule`` — ``schedule()``, ``weekly()``
- ``teams``    — ``franchises()``, ``roster()``, ``standings()``, ``player()``
"""
from sportly.nhl.endpoints import (  # noqa: F401
    games,
    schedule,
    teams,
)
